Learn R Programming

dotsViolin (version 0.0.1)

get.peaks: Get peaks of a continuous variable

Description

This function allows you to get peaks for a continuous variable. Based on the kernel density function

Usage

get.peaks(x, bw, signifi, nsmall, ranks = 3)

Value

data.frame

Arguments

x

dataframe

bw

bandwidth

signifi

criteria to bin the data in number of digits

nsmall

criteria to approximate (round) data

ranks

numeric how many ranks to consider