Learn R Programming

dotsViolin (version 0.0.1)

get_peaks_counts_continuous: Peaks of a continuous variable in a dataframe format

Description

This function allows you to get peaks and summary counts per group for a continuos variable in a dataframe format. Handles ties; least frequent is ignored, except if it is the only one, depends on get.peaks function

Usage

get_peaks_counts_continuous(
  origtable,
  grouping_col,
  columnname,
  peak_number,
  adjust1,
  signifi,
  nsmall
)

Value

data.frame

Arguments

origtable

dataframe

grouping_col

column with categories - character

columnname

column with numerical data

peak_number

number of peaks to get, see get.peaks

adjust1

bandwith adjust parameter

signifi

see get.peaks function

nsmall

see get.peaks function

Examples

Run this code
get_peaks_counts_continuous(fabaceae_clade_1Cx_df, "clade", "Cx", 2, 0.25, 1, 2)

Run the code above in your browser using DataLab