get_peaks_counts_continuous: Peaks of a continuous variable in a dataframe format
Description
This function allows you to get peaks and summary counts per group for a continuos variable in a dataframe format.
Handles ties; least frequent is ignored, except if it is the only
one, depends on get.peaks function